@@ -126,7 +126,7 @@ fill_locf <- function(data, fixed, random, auxvars, timevar, groups) {
   # (needed because otherwise "groups" would not fit any more after sorting)
   # and sort the data by the time variable
   data$rowiddd <- seq_len(nrow(data))
-  data <- data[order(data[timevar]), ]
+  data <- data[order(data[[timevar]]), ]
 
   # split the data by patient, and fill in values in the time-varying variables
   datlist <- lapply(split(data, data[surv_lvl]), function(x) {
@@ -559,9 +559,9 @@ get_linpreds <- function(fixed, random, data, models, auxvars = NULL,
   # term labels.
   auxterms <- if (!is.null(auxvars)) attr(terms(auxvars), "term.labels")
 
-  covar_terms <- c(all_vars(c(remove_lhs(fixed),
-                              remove_grouping(random))),
-                   auxterms)
+  covar_terms <- unique(c(all_vars(c(remove_lhs(fixed),
+                                     remove_grouping(random))),
+                          auxterms))
 
 
 
@@ -619,7 +619,7 @@ get_linpreds <- function(fixed, random, data, models, auxvars = NULL,
 
     keep_terms <- lvapply(covar_terms, function(k) {
       check_effect <- try(model.frame(paste0("~", k), testdat), silent = TRUE)
-      !inherits(check_effect, "try-error")
+      !inherits(check_effect, "try-error") & k %in% names(testdat)
     })
 
     covar_terms <- covar_terms[keep_terms]
